# WARNING: This package is synced with FC

# we build CUPS also with relro
%global _hardened_build 0

%define libname %mklibname %{name} 1
%define develname %mklibname -d %{name}

Summary: OpenPrinting CUPS filters and backends
Name:    cups-filters
Version: 1.13.4
%define subrel 2
Release: %mkrel 2

# For a breakdown of the licensing, see COPYING file
# GPLv2:   filters: commandto*, imagetoraster, pdftops, rasterto*,
#                   imagetopdf, pstopdf, texttopdf
#         backends: parallel, serial
# GPLv2+:  filters: gstopxl, textonly, texttops, imagetops, foomatic-rip
# GPLv3:   filters: bannertopdf
# GPLv3+:  filters: urftopdf, rastertopdf
# LGPLv2+:   utils: cups-browsed
# MIT:     filters: gstoraster, pdftoijs, pdftoopvp, pdftopdf, pdftoraster
License: GPLv2 and GPLv2+ and GPLv3 and GPLv3+ and LGPLv2+ and MIT

Group:   System/Printing
Url:     http://www.linuxfoundation.org/collaborate/workgroups/openprinting/cups-filters
Source0: http://www.openprinting.org/download/cups-filters/cups-filters-%{version}.tar.xz
Source1: cups-browsed.service

# Fedora patches:
Patch01: cups-filters-apremotequeueid.patch

Requires: %{libname} = %{version}-%{release}

Obsoletes: php-cups

BuildRequires: cups-devel
BuildRequires: pkgconfig(ijs)
# pdftopdf
BuildRequires: pkgconfig(libqpdf)
# pdftops
BuildRequires: poppler
# pdftoijs, pdftoopvp, pdftoraster
BuildRequires: pkgconfig(poppler)
BuildRequires: pkgconfig(poppler-cpp)
BuildRequires: libjpeg-devel
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(libtiff-4)
BuildRequires: pkgconfig(zlib)
# libijs
BuildRequires: ghostscript-devel
BuildRequires: freetype-devel
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(lcms2)
# cups-browsed
BuildRequires: pkgconfig(avahi-core)
BuildRequires: pkgconfig(avahi-glib)
BuildRequires: systemd
# configure needs /bin/gs (mga#11684):
BuildRequires: ghostscript

# Make sure we get postscriptdriver tags.
BuildRequires: python-cups

# Testing font for test scripts.
BuildRequires: fonts-ttf-dejavu

# autogen.sh
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool

Requires: cups-filesystem
Requires: poppler
# texttopdf
Requires: fonts-ttf-liberation
# pstopdf
Requires: bc
Conflicts: cups < 1.6.2-3
Conflicts: ghostscript-common < 9.09

Provides: foomatic-filters = 4.0.17-3.mga4
Obsoletes: foomatic-filters < 4.0.17-3.mga4

# cups-browsed
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%package -n %{libname}
Summary: OpenPrinting CUPS filters and backends - cupsfilters and fontembed libraries
Group:   System/Libraries
# LGPLv2: libcupsfilters
# MIT:    libfontembed
License: LGPLv2 and MIT

%package -n %{develname}
Summary: OpenPrinting CUPS filters and backends - development environment
Group:   Development/C
License: LGPLv2 and MIT
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description
Contains backends, filters, and other software that was
once part of the core CUPS distribution but is no longer maintained by
Apple Inc. In addition it contains additional filters developed
independently of Apple, especially filters for the PDF-centric printing
workflow introduced by OpenPrinting.

%description -n %{libname}
This package provides cupsfilters and fontembed libraries.

%description -n %{develname}
This is the development package for OpenPrinting CUPS filters and backends.

%prep
%setup -q
%autopatch -p1

%build
# work-around Rpath
./autogen.sh

export CXXFLAGS="%{optflags} -std=c++11"

# --with-pdftops=hybrid - use Poppler's pdftops instead of Ghostscript for
#                         Brother, Minolta, and Konica Minolta to work around
#                         bugs in the printer's PS interpreters
# --with-rcdir=no - don't install SysV init script
%configure2_5x --disable-static \
           --disable-silent-rules \
           --with-pdftops=hybrid \
           --enable-dbus \
           --disable-mutool \
           --with-rcdir=no

%make

%install
%makeinstall_std

# https://fedoraproject.org/wiki/Packaging_tricks#With_.25doc
mkdir __doc
mv  %{buildroot}%{_datadir}/doc/cups-filters/* __doc
rm -rf %{buildroot}%{_datadir}/doc/cups-filters

# Don't ship libtool la files.
rm -f %{buildroot}%{_libdir}/lib*.la

# Not sure what is this good for.
rm -f %{buildroot}%{_bindir}/ttfread

# systemd unit file
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 utils/cups-browsed.service %{buildroot}%{_unitdir}

# LSB3.2 requires /usr/bin/foomatic-rip,
# create it temporarily as a relative symlink
ln -sf %{_cups_serverbin}/filter/foomatic-rip %{buildroot}%{_bindir}/foomatic-rip

# imagetobrf is going to be mapped as /usr/lib/cups/filter/imagetoubrl
ln -sf imagetobrf %{buildroot}%{_cups_serverbin}/filter/imagetoubrl

# textbrftoindex3 is going to be mapped as /usr/lib/cups/filter/textbrftoindexv4
ln -sf textbrftoindexv3 %{buildroot}%{_cups_serverbin}/filter/textbrftoindexv4

# Don't ship urftopdf for now (bug #1002947).
rm -f %{buildroot}%{_cups_serverbin}/filter/urftopdf
sed -i '/urftopdf/d' %{buildroot}%{_datadir}/cups/mime/cupsfilters.convs

# Don't ship pdftoopvp for now (bug #1027557).
rm -f %{buildroot}%{_cups_serverbin}/filter/pdftoopvp
rm -f %{buildroot}%{_sysconfdir}/fonts/conf.d/99pdftoopvp.conf


%check
#make check

%post
%_post_service cups-browsed

# Initial installation
if [ $1 -eq 1 ] ; then
    IN=%{_sysconfdir}/cups/cupsd.conf
    OUT=%{_sysconfdir}/cups/cups-browsed.conf
    keyword=BrowsePoll

    # We can remove this after few releases, it's just for the introduction of cups-browsed.
    if [ -f "$OUT" ]; then
        echo -e "\n# NOTE: This file is not part of CUPS.\n# You need to enable cups-browsed service\n# and allow ipp-client service in firewall." >> "$OUT"
    fi

    # move BrowsePoll from cupsd.conf to cups-browsed.conf
    if [ -f "$IN" ] && grep -iq ^$keyword "$IN"; then
        if ! grep -iq ^$keyword "$OUT"; then
            (cat >> "$OUT" <<EOF

# Settings automatically moved from cupsd.conf by RPM package:
EOF
            ) || :
            (grep -i ^$keyword "$IN" >> "$OUT") || :
            #systemctl enable cups-browsed.service >/dev/null 2>&1 || :
        fi
        sed -i -e "s,^$keyword,#$keyword directive moved to cups-browsed.conf\n#$keyword,i" "$IN" || :
    fi
fi

%preun
%_preun_service cups-browsed

%postun
%_postun_service cups-browsed

%files
%doc __doc/README __doc/AUTHORS __doc/NEWS
%config(noreplace) %{_sysconfdir}/cups/cups-browsed.conf
%attr(0755,root,root) /usr/lib/cups/filter/*
%attr(0755,root,root) /usr/lib/cups/backend/parallel
# Serial backend needs to run as root (bug #212577#c4).
%attr(0700,root,root) /usr/lib/cups/backend/serial
%attr(0755,root,root) %{_cups_serverbin}/backend/implicitclass
%attr(0755,root,root) %{_cups_serverbin}/backend/beh
%{_bindir}/foomatic-rip
%{_bindir}/driverless
%{_cups_serverbin}/backend/driverless
%{_cups_serverbin}/driver/driverless
%{_datadir}/cups/banners
%{_datadir}/cups/braille
%{_datadir}/cups/charsets
%{_datadir}/cups/data/*
# this needs to be in the main package because of cupsfilters.drv
%{_datadir}/cups/ppdc/pcl.h
%{_datadir}/cups/ppdc/braille.defs
%{_datadir}/cups/ppdc/fr-braille.po
%{_datadir}/cups/ppdc/imagemagick.defs
%{_datadir}/cups/ppdc/index.defs
%{_datadir}/cups/ppdc/liblouis.defs
%{_datadir}/cups/ppdc/liblouis1.defs
%{_datadir}/cups/ppdc/liblouis2.defs
%{_datadir}/cups/ppdc/liblouis3.defs
%{_datadir}/cups/ppdc/liblouis4.defs
%{_datadir}/cups/ppdc/media-braille.defs
%{_datadir}/cups/drv/cupsfilters.drv
%{_datadir}/cups/drv/generic-brf.drv
%{_datadir}/cups/drv/indexv3.drv
%{_datadir}/cups/drv/indexv4.drv
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/cups/mime/cupsfilters-ghostscript.convs
#{_datadir}/cups/mime/cupsfilters-mupdf.convs
%{_datadir}/cups/mime/cupsfilters-poppler.convs
%{_datadir}/cups/mime/braille.convs
%{_datadir}/cups/mime/braille.types
%{_datadir}/ppd/cupsfilters
%{_sbindir}/cups-browsed
%{_unitdir}/cups-browsed.service
%{_mandir}/man8/cups-browsed.8.*
%{_mandir}/man5/cups-browsed.conf.5.*
%{_mandir}/man1/foomatic-rip.1.*
%{_mandir}/man1/driverless.1.*

%files -n %{libname}
%doc __doc/COPYING fontembed/README
%{_libdir}/libcupsfilters.so.*
%{_libdir}/libfontembed.so.*

%files -n %{develname}
%{_includedir}/cupsfilters
%{_includedir}/fontembed
%{_datadir}/cups/ppdc/escp.h
%{_libdir}/pkgconfig/libcupsfilters.pc
%{_libdir}/pkgconfig/libfontembed.pc
%{_libdir}/libcupsfilters.so
%{_libdir}/libfontembed.so



%changelog
* Tue Feb 20 2018 kekepower <kekepower> 1.13.4-2.2.mga6
+ Revision: 1203544
- Rebuild for new qpdf

  + akien <akien>
    - Rebuild against qpdf-6.0.0-2.20170730.1.mga6 (mga#21444)

* Fri May 26 2017 neoclust <neoclust> 1.13.4-2.mga6
+ Revision: 1104821
- Rebuild to see if it help to fix a crash

* Sun Mar 26 2017 tv <tv> 1.13.4-1.mga6
+ Revision: 1094860
- 1.13.4
- Added queues are not marked as remote ones (rhbz#1426567)

* Thu Jan 05 2017 tv <tv> 1.13.2-1.mga6
+ Revision: 1080230
- new release

* Mon Jan 02 2017 luigiwalser <luigiwalser> 1.13.0-2.mga6
+ Revision: 1079506
- rebuild for poppler

* Thu Dec 15 2016 tv <tv> 1.13.0-1.mga6
+ Revision: 1075323
- new release
- explicitely disable mutool as we don't have mupdf anymore

* Mon Nov 28 2016 luigiwalser <luigiwalser> 1.11.4-2.mga6
+ Revision: 1070612
- rebuild for poppler

* Fri Sep 30 2016 tv <tv> 1.11.4-1.mga6
+ Revision: 1057857
- new release

* Fri Sep 16 2016 tv <tv> 1.11.3-1.mga6
+ Revision: 1053443
- new version

* Thu Sep 15 2016 tv <tv> 1.11.2-1.mga6
+ Revision: 1053130
- new version

* Sat Aug 13 2016 luigiwalser <luigiwalser> 1.9.0-2.mga6
+ Revision: 1046172
- test rebuild for poppler

* Sat Jun 11 2016 tv <tv> 1.9.0-1.mga6
+ Revision: 1021135
- new release

* Wed May 25 2016 luigiwalser <luigiwalser> 1.8.3-3.mga6
+ Revision: 1018536
- rebuild for poppler

* Mon May 09 2016 luigiwalser <luigiwalser> 1.8.3-2.mga6
+ Revision: 1011747
- rebuild for poppler

* Tue Mar 29 2016 tv <tv> 1.8.3-1.mga6
+ Revision: 996094
- new release

* Sun Feb 14 2016 tv <tv> 1.8.2-1.mga6
+ Revision: 959968
- 1.8.2

* Fri Jan 22 2016 tv <tv> 1.8.1-1.mga6
+ Revision: 926481
- new release

* Fri Jan 22 2016 tv <tv> 1.8.0-1.mga6
+ Revision: 926415
- new release

* Tue Jan 19 2016 tv <tv> 1.7.0-1.mga6
+ Revision: 925921
- new release

* Mon Jan 18 2016 luigiwalser <luigiwalser> 1.6.0-2.mga6
+ Revision: 925489
- rebuild for qpdf

* Thu Jan 14 2016 tv <tv> 1.6.0-1.mga6
+ Revision: 923019
- adjust file list
- new release
- new release

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1.5.0-2.mga6
+ Revision: 917800
- rebuild for poppler

* Sat Dec 19 2015 tv <tv> 1.5.0-1.mga6
+ Revision: 912074
- new release

* Tue Dec 15 2015 tv <tv> 1.4.0-1.mga6
+ Revision: 910755
- new release

* Sun Dec 13 2015 luigiwalser <luigiwalser> 1.3.0-2.mga6
+ Revision: 910248
- add upstream patch to fix incomplete escaping in foomatic-rip

* Thu Dec 10 2015 tv <tv> 1.3.0-1.mga6
+ Revision: 909342
- new release
- notice that this package is synced with FC

* Fri Nov 27 2015 tv <tv> 1.2.0-1.mga6
+ Revision: 906458
- 1.2.0

* Thu Oct 29 2015 tv <tv> 1.1.0-1.mga6
+ Revision: 896177
- new release

* Sun Sep 13 2015 tv <tv> 1.0.76-1.mga6
+ Revision: 878893
- new release

* Tue Sep 08 2015 tv <tv> 1.0.75-1.mga6
+ Revision: 874039
- new release

* Fri Aug 28 2015 tv <tv> 1.0.74-1.mga6
+ Revision: 870414
- new release
- new release

* Sat Jul 25 2015 tv <tv> 1.0.71-2.mga6
+ Revision: 857578
- switch to %%autopatch -p0
- rebuild for new poppler
- new release

* Sat Jul 04 2015 luigiwalser <luigiwalser> 1.0.71-1.mga6
+ Revision: 850569
- 1.0.71 (fixes CVE-2015-3279)

* Mon Jun 29 2015 tv <tv> 1.0.70-1.mga6
+ Revision: 847563
- 1.0.70 (fixes CVE-2015-3258)

* Thu Jun 25 2015 tv <tv> 1.0.69-2.mga6
+ Revision: 842817
- rebuild for new poppler

* Sun Jun 21 2015 tv <tv> 1.0.69-1.mga6
+ Revision: 837659
- new release

* Fri Mar 13 2015 luigiwalser <luigiwalser> 1.0.67-1.mga5
+ Revision: 818482
- 1.0.67 (fixes lp#1427344)

* Wed Mar 04 2015 tv <tv> 1.0.66-1.mga5
+ Revision: 817628
- new release

* Wed Feb 18 2015 tv <tv> 1.0.65-1.mga5
+ Revision: 815634
- new version

* Wed Feb 18 2015 neoclust <neoclust> 1.0.61-2.mga5
+ Revision: 815609
- Remove wrong obsoletes

* Thu Oct 23 2014 tv <tv> 1.0.61-1.mga5
+ Revision: 792586
- new release
- drop merged patch

* Wed Oct 15 2014 umeabot <umeabot> 1.0.58-5.mga5
+ Revision: 742159
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 luigiwalser <luigiwalser> 1.0.58-4.mga5
+ Revision: 737588
- add upstream patch to fix segfault in foomatic-rip (upstream bug #1227)

* Thu Sep 18 2014 umeabot <umeabot> 1.0.58-3.mga5
+ Revision: 693712
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0.58-2.mga5
+ Revision: 678634
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 tv <tv> 1.0.58-1.mga5
+ Revision: 666360
- new release

* Thu Jul 31 2014 tv <tv> 1.0.55-1.mga5
+ Revision: 658807
- new release

* Fri Jun 20 2014 tv <tv> 1.0.54-3.mga5
+ Revision: 638233
- sync patches with FC

* Sun Jun 15 2014 ovitters <ovitters> 1.0.54-2.mga5
+ Revision: 636465
- obsoletes printer-filters,printer-filters-doc

* Wed Jun 11 2014 tv <tv> 1.0.54-1.mga5
+ Revision: 635582
- new release

* Tue Jun 03 2014 luigiwalser <luigiwalser> 1.0.53-2.mga5
+ Revision: 632611
- restore patch for rhbz#768811 from fedora

* Mon Apr 28 2014 tv <tv> 1.0.53-1.mga5
+ Revision: 618749
- disable testsuite again
- new release
- reenable test suite

* Mon Apr 14 2014 tv <tv> 1.0.52-1.mga5
+ Revision: 614275
- new release

* Fri Apr 04 2014 tv <tv> 1.0.51-1.mga5
+ Revision: 611614
- new release

* Fri Mar 28 2014 tv <tv> 1.0.50-1.mga5
+ Revision: 609160
- new release

* Thu Mar 27 2014 tv <tv> 1.0.49-1.mga5
+ Revision: 608904
- new release

* Thu Mar 20 2014 tv <tv> 1.0.48-1.mga5
+ Revision: 606264
- adjust file list
- new release
- sync patches with RH
- new release
- sync patches with RH

* Thu Mar 13 2014 tv <tv> 1.0.46-3.mga5
+ Revision: 603246
- rebuild for "new" libqpdf

* Sat Feb 22 2014 tv <tv> 1.0.46-2.mga5
+ Revision: 595473
- fix printing: configure needs /bin/gs (mga#11684)

* Thu Feb 20 2014 tv <tv> 1.0.46-1.mga5
+ Revision: 595164
- new release

* Sat Feb 15 2014 tv <tv> 1.0.45-1.mga5
+ Revision: 591607
- new release

* Fri Feb 07 2014 tv <tv> 1.0.44-2.mga5
+ Revision: 584974
- fix upgrade

* Fri Feb 07 2014 tv <tv> 1.0.44-1.mga5
+ Revision: 584956
- new release
- obsoletes foomatic-filters
- add /usr/bin/foomatic-rip symlink, due to LSB3.2 (rhbz#1052452)

* Tue Nov 19 2013 tv <tv> 1.0.41-3.mga5
+ Revision: 551952
- adjust filter costs so application/vnd.adobe-read-postscript input
  doesn't go via pstotiff (rhbz#1008166)

* Tue Nov 19 2013 tv <tv> 1.0.41-2.mga4
+ Revision: 551865
- fix memory leaks in cups-browsed (rhbz#1027317)
- include dbus so that colord support works (rhbz#1026928)

* Wed Oct 30 2013 tv <tv> 1.0.41-1.mga4
+ Revision: 548025
- new release

* Tue Oct 22 2013 umeabot <umeabot> 1.0.40-3.mga4
+ Revision: 542055
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 tv <tv> 1.0.40-2.mga4
+ Revision: 496793
- fix PDF landscape printing (rhbz#768811)

* Fri Oct 11 2013 tv <tv> 1.0.40-1.mga4
+ Revision: 495218
- new release
- use new "hybrid" pdftops renderer

* Thu Oct 03 2013 tv <tv> 1.0.39-1.mga4
+ Revision: 490971
- new release

* Thu Oct 03 2013 tv <tv> 1.0.38-2.mga4
+ Revision: 490877
- sync with FC:
  o Use IPP notifications for BrowsePoll when possible (rhbz#975241)
  o Fixes for some printf-type format mismatches (rhbz#1014093)
- patch 1: fix landscape printing for PDFs (bug rhbz#768811)

* Thu Sep 12 2013 tv <tv> 1.0.38-1.mga4
+ Revision: 478016
- new release

* Sat Aug 31 2013 tv <tv> 1.0.37-2.mga4
+ Revision: 473751
- conflicts with older ghostscript-common for upgrade

* Fri Aug 30 2013 tv <tv> 1.0.37-1.mga4
+ Revision: 473432
- disable test suite
- new release
- run make check
- new release

* Wed Jul 31 2013 fwang <fwang> 1.0.35-5.mga4
+ Revision: 461346
- rebuild for new poppler

* Sat Jul 27 2013 tv <tv> 1.0.35-4.mga4
+ Revision: 458740
- requires cups-filesystem instead of cups

* Sat Jul 27 2013 tv <tv> 1.0.35-3.mga4
+ Revision: 458736
- sync with FC:
  o added support for page-label (rhz#987515)
  o add cups-browsed(8) and cups-browsed.conf(5)
  o don't reverse lookup IP address in URI (rhz#975822)

* Sat Jul 20 2013 fwang <fwang> 1.0.35-2.mga4
+ Revision: 456552
- more patch
- more patch
- add include
- update format
- try fix building with recent poppler
- rebuild for new poppler

  + tv <tv>
    - fix URL

* Sat Jun 29 2013 tv <tv> 1.0.35-1.mga4
+ Revision: 448307
- new release

* Thu Jun 20 2013 tv <tv> 1.0.34-8.mga4
+ Revision: 445204
- fix the note we add in cups-browsed.conf

* Thu Jun 13 2013 tv <tv> 1.0.34-7.mga4
+ Revision: 442559
- use our services macros rather than FC ones)

* Thu Jun 13 2013 tv <tv> 1.0.34-6.mga4
+ Revision: 442544
- prevent %%systemd_(pre|post)un to fail (ignoring status)

* Thu Jun 13 2013 tv <tv> 1.0.34-5.mga4
+ Revision: 442524
- obsolete php-cups as it has been picked by cups-filters but is broken
- cupsfilters.drv needs ppdc/pcl.h
- pstopdf requires bc
- mem leaks fixes from FC

* Tue Jun 04 2013 fwang <fwang> 1.0.34-4.mga4
+ Revision: 437124
- fix conflicts

* Tue Jun 04 2013 tv <tv> 1.0.34-3.mga4
+ Revision: 437104
- conflicts with older cups

* Tue Jun 04 2013 fwang <fwang> 1.0.34-2.mga4
+ Revision: 437054
- update requires

* Wed May 29 2013 tv <tv> 1.0.34-1.mga4
+ Revision: 430294
- imported package cups-filters

